@@ -10,13 +10,11 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
-#
-# 
-#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Core::Domain;
 
+use utf8;
 use strict;
 use warnings;
 
@@ -24,8 +22,6 @@ use Net::DRI::Util;
 use Net::DRI::Exception;
 use Net::DRI::Protocol::EPP::Util;
 
-our $VERSION=do { my @r=(q$Revision: 1.22 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
-
 =pod
 
 =head1 NAME
@@ -403,7 +399,7 @@ sub update
 }
 
 ####################################################################################################
-## RFC4931 3.3  Offline Review of Requested Actions
+## RFC4931 §3.3  Offline Review of Requested Actions
 
 sub pandata_parse
 {
