@@ -1,6 +1,6 @@
 ## Domain Registry Interface, AFNIC (.FR/.RE) Contact EPP extension commands
 ##
-## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008,2009 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,19 +10,16 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
-#
-# 
-#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::AFNIC::Contact;
 
 use strict;
+use warnings;
 
+use Net::DRI::Util;
 use Net::DRI::Exception;
 
-our $VERSION=do { my @r=(q$Revision: 1.3 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
-
 =pod
 
 =head1 NAME
@@ -51,7 +48,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008,2009 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -92,18 +89,21 @@ sub create
 
 ## validate() has been called
  my @n;
- if ($contact->org() && $contact->legal_form()) # PM
+ if ($contact->legal_form()) # PM
  {
   my @d;
   Net::DRI::Exception::usererr_insufficient_parameters('legal_form data mandatory') unless ($contact->legal_form());
   Net::DRI::Exception::usererr_invalid_parameters('legal_form_other data mandatory if legal_form=other') if (($contact->legal_form() eq 'other') && !$contact->legal_form_other());
-  push @d,['frnic:legalStatus',{type => $contact->legal_form()},$contact->legal_form() eq 'other'? $contact->legal_form_other() : ''];
+  push @d,['frnic:legalStatus',{s => $contact->legal_form()},$contact->legal_form() eq 'other'? $contact->legal_form_other() : ''];
   push @d,['frnic:siren',$contact->legal_id()] if $contact->legal_id();
+  push @d,['frnic:VAT',$contact->vat()] if $contact->vat();
   push @d,['frnic:trademark',$contact->trademark()] if $contact->trademark();
   my $jo=$contact->jo();
   if (defined($jo) && (ref($jo) eq 'HASH'))
   {
    my @j;
+   push @j,['frnic:waldec',$jo->{waldec}] if exists $jo->{waldec};
+   push @j,['frnic:waldec',$contact->legal_id()] if (defined $contact->legal_id() && defined $contact->legal_form_other() && $contact->legal_form_other() eq 'asso'); ## not sure API ok
    push @j,['frnic:decl',$jo->{date_declaration}];
    push @j,['frnic:publ',{announce=>$jo->{number},page=>$jo->{page}},$jo->{date_publication}];
    push @d,['frnic:asso',@j];
@@ -111,22 +111,27 @@ sub create
   push @n,['frnic:legalEntityInfos',@d];
  } else # PP
  {
-  push @n,['frnic:list','restrictedPublication'] if ($contact->disclose() eq 'N');
   my @d;
   my $b=$contact->birth();
-  Net::DRI::Exception::usererr_insufficient_parameters('birth data mandatory') unless ($b && (ref($b) eq 'HASH') && exists($b->{date}) && exists($b->{place}));
-  push @d,['frnic:birthDate',(ref($b->{date}))? $b->{date}->strftime('%Y-%m-%d') : $b->{date}];
-  if ($b->{place}=~m/^[A-Z]{2}$/i) ## country not France
+  if (Net::DRI::Util::has_key($b,'date') && Net::DRI::Util::has_key($b,'place'))
   {
-   push @d,['frnic:birthCc',$b->{place}];
-  } else
+   push @d,['frnic:birthDate',ref $b->{date} ? $b->{date}->strftime('%Y-%m-%d') : $b->{date}];
+   if ($b->{place}=~m/^[A-Z]{2}$/i) ## country not France
+   {
+    push @d,['frnic:birthCc',$b->{place}];
+   } else
+   {
+    my @p=($b->{place}=~m/^\s*(\S.*\S)\s*,\s*(\S.+\S)\s*$/);
+    push @d,['frnic:birthCity',$p[1]];
+    push @d,['frnic:birthPc',$p[0]];
+    push @d,['frnic:birthCc','FR'];
+   }
+  }
+  if (@d)
   {
-   my @p=($b->{place}=~m/^\s*(\S.*\S)\s*,\s*(\S.+\S)\s*$/);
-   push @d,['frnic:birthCity',$p[1]];
-   push @d,['frnic:birthPc',$p[0]];
-   push @d,['frnic:birthCc','FR'];
+   push @n,['frnic:list','restrictedPublication'] if (defined $contact->disclose() && $contact->disclose() eq 'N');
+   push @n,['frnic:individualInfos',@d];
   }
-  push @n,['frnic:individualInfos',@d];
   push @n,['frnic:firstName',$contact->firstname()];
  }
 
@@ -141,29 +146,24 @@ sub create_parse
  return unless $mes->is_success();
 
  my $credata=$mes->get_extension('frnic','ext');
- return unless $credata;
+ return unless defined $credata;
+
  my $ns=$mes->ns('frnic');
- my $c=$credata->getChildrenByTagNameNS($ns,'resData');
- return unless $c->size();
- $c=$c->shift()->getChildrenByTagNameNS($ns,'creData');
- return unless $c->size();
+ $credata=Net::DRI::Util::xml_traverse($credata,$ns,'resData','creData');
+ return unless defined $credata;
 
  $oname=$rinfo->{contact}->{$oname}->{id}; ## take into account true ID (the one returned by the registry)
- $c=$c->shift()->getFirstChild();
- while($c)
+ foreach my $el (Net::DRI::Util::xml_list_children($credata))
  {
-  next unless ($c->nodeType() == 1); ## only for element nodes
-  my $name=$c->localname() || $c->nodeName();
-  next unless $name;
-
+  my ($name,$c)=@$el;
   if ($name eq 'nhStatus')
   {
-   $rinfo->{contact}->{$oname}->{new_handle}=$c->getAttribute('new');
+   $rinfo->{contact}->{$oname}->{new_handle}=Net::DRI::Util::xml_parse_boolean($c->getAttribute('new'));
   } elsif ($name eq 'idStatus')
   {
-   $rinfo->{contact}->{$oname}->{identification}=$c->getFirstChild()->getData();
+   $rinfo->{contact}->{$oname}->{identification}=$c->textContent();
   }
- } continue { $c=$c->getNextSibling(); }
+ }
 }
 
 sub update
@@ -189,97 +189,83 @@ sub info_parse
  return unless $mes->is_success();
 
  my $infdata=$mes->get_extension('frnic','ext');
- return unless $infdata;
+ return unless defined $infdata;
+
  my $ns=$mes->ns('frnic');
- my $c=$infdata->getChildrenByTagNameNS($ns,'resData');
- return unless $c->size();
- $c=$c->shift()->getChildrenByTagNameNS($ns,'infData');
- return unless $c->size();
- $c=$c->shift()->getChildrenByTagNameNS($ns,'contact');
- return unless $c->size();
+ $infdata=Net::DRI::Util::xml_traverse($infdata,$ns,'resData','infData','contact');
+ return unless defined $infdata;
 
  my $co=$rinfo->{contact}->{$oname}->{self};
- $c=$c->shift()->getFirstChild();
- while($c)
+ foreach my $el (Net::DRI::Util::xml_list_children($infdata))
  {
-  next unless ($c->nodeType() == 1); ## only for element nodes
-  my $name=$c->localname() || $c->nodeName();
-  next unless $name;
-
+  my ($name,$c)=@$el;
   if ($name eq 'firstName')
   {
    $co->firstname($c->textContent());
   } elsif ($name eq 'list')
   {
-   my $v=$c->getFirstChild()->getData();
-   $co->disclose($v eq 'restrictedPublication'? 'N' : 'Y');
+   $co->disclose($c->textContent() eq 'restrictedPublication'? 'N' : 'Y');
   } elsif ($name eq 'individualInfos')
   {
-    my $cc=$c->getFirstChild();
     my %b;
-    while($cc)
+    foreach my $sel (Net::DRI::Util::xml_list_children($c))
     {
-      next unless ($cc->nodeType() == 1);
-      my $nn=$cc->localname() || $c->nodeName();
-      next unless $nn;
-
-      if ($nn eq 'idStatus')
-      {
-        $rinfo->{contact}->{$oname}->{identification}=$cc->getFirstChild()->getData();
-      } elsif ($nn eq 'birthDate')
-      {
-        $b{date}=$cc->getFirstChild()->getData();
-      } elsif ($nn eq 'birthCity')
-      {
-        $b{place}=$cc->getFirstChild()->getData();
-      } elsif ($nn eq 'birthPc')
-      {
-       $b{place}=sprintf('%s, %s',$cc->getFirstChild()->getData(),$b{place});
-      } elsif ($nn eq 'birthCc')
-      {
-       my $v=$cc->getFirstChild()->getData();
-       $b{place}=$v unless ($v eq 'FR');
-      }
-    } continue { $cc=$cc->getNextSibling(); }
+     my ($nn,$cc)=@$sel;
+     if ($nn eq 'idStatus')
+     {
+      $rinfo->{contact}->{$oname}->{identification}=$cc->textContent();
+     } elsif ($nn eq 'birthDate')
+     {
+      $b{date}=$cc->textContent();
+     } elsif ($nn eq 'birthCity')
+     {
+      $b{place}=$cc->textContent();
+     } elsif ($nn eq 'birthPc')
+     {
+      $b{place}=sprintf('%s, %s',$cc->textContent(),$b{place});
+     } elsif ($nn eq 'birthCc')
+     {
+      my $v=$cc->textContent();
+      $b{place}=$v unless ($v eq 'FR');
+     }
+    }
     $co->birth(\%b);
   } elsif ($name eq 'legalEntityInfos')
   {
-    my $cc=$c->getFirstChild();
-    while($cc)
+   foreach my $sel (Net::DRI::Util::xml_list_children($c))
+   {
+    my ($nn,$cc)=@$sel;
+    if ($nn eq 'legalStatus')
     {
-      next unless ($cc->nodeType() == 1);
-      my $nn=$cc->localname() || $c->nodeName();
-      next unless $nn;
-
-      if ($nn eq 'legalStatus')
-      {
-       $co->legal_form($cc->getAttribute('type'));
-       my $v=$cc->getFirstChild()->getData();
-       $co->legal_form_other($v) if $v;
-      } elsif ($nn eq 'siren')
-      {
-       $co->legal_id($cc->getFirstChild()->getData());
-      } elsif ($nn eq 'trademark')
-      {
-       $co->trademark($cc->getFirstChild()->getData());
-      } elsif ($nn eq 'asso')
-      {
-        my %jo;
-        my $ccc=$cc->getChildrenByTagNameNS($mes->ns('frnic'),'decl');
-        $jo{date_declaration}=$ccc->shift()->getFirstChild()->getData() if ($ccc->size());
-        $ccc=$cc->getChildrenByTagNameNS($mes->ns('frnic'),'publ');
-        if ($ccc->size())
-        {
-          my $p=$ccc->shift();
-          $jo{number}=$p->getAttribute('announce');
-          $jo{page}=$p->getAttribute('page');
-          $jo{date_publication}=$p->getFirstChild()->getData();
-        }
-        $co->jo(\%jo);
-      }
-    } continue { $cc=$cc->getNextSibling(); }
+     $co->legal_form($cc->getAttribute('type'));
+     my $v=$cc->textContent();
+     $co->legal_form_other($v) if $v;
+    } elsif ($nn eq 'siren')
+    {
+     $co->legal_id($cc->textContent());
+    } elsif ($nn eq 'trademark')
+    {
+     $co->trademark($cc->textContent());
+    } elsif ($nn eq 'asso')
+    {
+     my %jo;
+     my $ccc=$cc->getChildrenByTagNameNS($mes->ns('frnic'),'decl');
+     $jo{date_declaration}=$ccc->get_node(1)->textContent() if ($ccc->size());
+     $ccc=$cc->getChildrenByTagNameNS($mes->ns('frnic'),'publ');
+     if ($ccc->size())
+     {
+      my $p=$ccc->get_node(1);
+      $jo{number}=$p->getAttribute('announce');
+      $jo{page}=$p->getAttribute('page');
+      $jo{date_publication}=$p->textContent();
+     }
+     $co->jo(\%jo);
+    }
+   }
   }
- } continue { $c=$c->getNextSibling(); }
+ }
+
+ return;
 }
 
 ####################################################################################################
