@@ -1,7 +1,7 @@
 ## Domain Registry Interface, EURid Sunrise EPP extension for Net::DRI
 ## (from registration_guidelines_v1_0F-appendix2-sunrise.pdf )
 ##
-## Copyright (c) 2005,2007,2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005,2007,2008,2009,2010 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,9 +11,6 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
-#
-# 
-#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::EURid::Sunrise;
@@ -25,11 +22,9 @@ use DateTime::Format::ISO8601;
 
 use Net::DRI::Util;
 use Net::DRI::Exception;
-use Net::DRI::Protocol::EPP::Core::Domain;
 use Net::DRI::Protocol::EPP::Extensions::EURid::Domain;
 use Net::DRI::DRD::EURid;
-
-our $VERSION=do { my @r=(q$Revision: 1.12 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+use Net::DRI::Protocol::EPP::Util;
 
 =pod
 
@@ -59,7 +54,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2007,2008 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005,2007,2008,2009 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -111,8 +106,6 @@ sub info_parse
  return unless $infdata;
 
  my $cs=Net::DRI::Data::ContactSet->new();
- my $cf=$po->factories()->{contact};
-
  my $pd=DateTime::Format::ISO8601->new();
  my $c=$infdata->firstChild();
  while ($c)
@@ -132,13 +125,13 @@ sub info_parse
    $rinfo->{domain}->{$oname}->{$1}=$pd->parse_datetime($c->firstChild->getData());
   } elsif ($name eq 'domain:registrant')
   {
-   $cs->set($cf->()->srid($c->firstChild->getData()),'registrant');
+   $cs->set($po->create_local_object('contact')->srid($c->firstChild->getData()),'registrant');
   } elsif ($name eq 'domain:contact')
   {
-   $cs->add($cf->()->srid($c->firstChild->getData()),$c->getAttribute('type'));
+   $cs->add($po->create_local_object('contact')->srid($c->firstChild->getData()),$c->getAttribute('type'));
   } elsif ($name eq 'domain:ns')
   {
-   $rinfo->{domain}->{$oname}->{ns}=Net::DRI::Protocol::EPP::Core::Domain::parse_ns($c);
+   $rinfo->{domain}->{$oname}->{ns}=Net::DRI::Protocol::EPP::Util::parse_ns($po,$c);
   } elsif ($name eq 'domain:adr')
   {
    $rinfo->{domain}->{$oname}->{adr}=Net::DRI::Util::xml_parse_boolean($c->firstChild->getData());
@@ -154,7 +147,7 @@ sub apply
 {
  my ($epp,$domain,$rd)=@_;
  my $mes=$epp->message();
- my @d=Net::DRI::Protocol::EPP::Core::Domain::build_command($mes,'apply',$domain);
+ my @d=Net::DRI::Protocol::EPP::Util::domain_build_command($mes,'apply',$domain);
 
  Net::DRI::Exception::usererr_insufficient_parameters('Apply action needs parameters') unless (defined($rd) && (ref($rd) eq 'HASH'));
  my @need=grep { !(exists($rd->{$_}) && $rd->{$_}) } qw/reference right prior-right-on-name prior-right-country documentaryevidence evidence-lang/;
@@ -187,7 +180,7 @@ sub apply
 
 
  ## Nameservers, OPTIONAL
- push @d,Net::DRI::Protocol::EPP::Core::Domain::build_ns($epp,$rd->{ns},$domain,'domain') if Net::DRI::Util::has_ns($rd);
+ push @d,Net::DRI::Protocol::EPP::Util::build_ns($epp,$rd->{ns},$domain,'domain') if Net::DRI::Util::has_ns($rd);
 
  ## Contacts, all OPTIONAL
  if (Net::DRI::Util::has_contact($rd))
@@ -195,7 +188,7 @@ sub apply
   my $cs=$rd->{contact};
   my @o=$cs->get('registrant');
   push @d,['domain:registrant',$o[0]->srid()] if (@o);
-  push @d,Net::DRI::Protocol::EPP::Core::Domain::build_contact_noregistrant($epp,$cs);
+  push @d,Net::DRI::Protocol::EPP::Util::build_core_contacts($epp,$cs);
  }
 
  $mes->command_body(\@d);
