@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Infrastructure ENUM .AT EPP extensions
 ##
-## Copyright (c) 2006,2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006,2008,2009 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,9 +10,6 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
-#
-# 
-#
 #########################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::IENUMAT;
@@ -21,8 +18,6 @@ use strict;
 
 use base qw/Net::DRI::Protocol::EPP/;
 
-our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
-
 =pod
 
 =head1 NAME
@@ -51,7 +46,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006,2008,2009 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -64,19 +59,15 @@ See the LICENSE file that comes with this distribution for more details.
 =cut
 
 ####################################################################################################
-sub new
+
+sub setup
 {
- my ($c,$drd,$version,$extrah)=@_;
- my %e=map { $_ => 1 } (defined($extrah)? (ref($extrah)? @$extrah : ($extrah)) : ());
-
- $e{'Net::DRI::Protocol::EPP::Extensions::AT::Result'}=1;
- $e{'Net::DRI::Protocol::EPP::Extensions::AT::IOptions'}=1;
- $e{'Net::DRI::Protocol::EPP::Extensions::E164'}=1;
-
- my $self=$c->SUPER::new($drd,$version,[keys(%e)]);
+ my ($self,$rp)=@_;
  $self->default_parameters()->{rfc4114_relax}=1;
- return $self;
+ return;
 }
 
+sub default_extensions { return qw/AT::Result AT::IOptions E164/; }
+
 ####################################################################################################
 1;
